<script setup lang="ts">
import { watch } from 'vue';

import { useVbenVxeGrid, type VxeGridProps, vxeSortEvent } from '#/adapter/vxe-table';
import { listRepairRecord } from '#/api/eims/repair-record';

import { columns } from '../repair-record/data';

interface Props {
  reqId?: string;
  resId?: string;
}

const props = defineProps<Props>();

const gridOptions: VxeGridProps = {
  checkboxConfig: {
    // 高亮
    highlight: true,
    // 翻页时保留选中状态
    reserve: true
    // 点击行选中
    // trigger: 'row'
  },
  columns,
  height: 'auto',
  keepSource: true,
  pagerConfig: {},
  proxyConfig: {
    ajax: {
      query: async ({ page }, formValues = {}) => {
        if (props.reqId) {
          const params = { reqId: props.reqId };
          Object.assign(formValues, params);
        } else if (props.resId) {
          const params = { resId: props.resId };
          Object.assign(formValues, params);
        } else {
          const params = { resId: -1 };
          Object.assign(formValues, params);
        }
        return await listRepairRecord({
          pageNum: page.currentPage,
          pageSize: page.pageSize,
          ...formValues
          // ...useRoleBaseFilters()
        });
      }
    }
  },
  rowConfig: {
    isHover: true,
    keyField: 'id'
  },
  sortConfig: {
    // 远程排序
    remote: true,
    // 支持多字段排序 默认关闭
    multiple: true
  },
  id: 'eims-repair-record-index'
};

const [BasicTable, tableApi] = useVbenVxeGrid({
  gridOptions,
  gridEvents: {
    sortChange: (sortParams) => vxeSortEvent(tableApi, sortParams)
  }
});

// 使用 watch 监听 resId 的变化
watch(
  () => props.reqId,
  (newVal, oldVal) => {
    if (newVal !== oldVal && newVal) {
      tableApi.query();
    }
  },
  { immediate: false }
);

// 使用 watch 监听 resId 的变化
watch(
  () => props.resId,
  (newVal, oldVal) => {
    if (newVal !== oldVal && newVal) {
      tableApi.query();
    }
  },
  { immediate: false }
);
</script>

<template>
  <div class="w-full">
    <BasicTable table-title="操作记录" />
  </div>
</template>
